NAME

drupal-upgrade - Script to perform drupal core upgrade

SYNOPSIS

drupal-upgrade [options] /path/to/new_drupal.tgz

Required arguments:
 --user        drupal admin user
 --password    drupal admin password
 --baseurl     base URL for the drupal site (no terminal slash)
 --basepath    base path for the drupal installation

Options:
 --tar         path to gnu tar

NOTES

This script overwrites the current drupal files with the new drupal files. It does NOT make any backups. Make sure you have a backup of your current drupal installation and database!

Script requires GNU tar to be in path, or specified as an option.